@@ -1,4 +1,4 @@
-"""Test CLI."""
+"""Tests for the morphology_workflows.cli module."""
 import re
 
 from morphology_workflows.tasks import cli
@@ -17,7 +17,7 @@ class TestCLI:
         assert (
             re.match(
                 r"usage: \S+ .*Run the workflow\n\npositional arguments:\s*"
-                r"{Fetch,Curate,Annotate,Repair}\s*Possible workflows.*",
+                r"{Fetch,Placeholders,Curate,Annotate,Repair}\s*Possible workflows.*",
                 captured.out,
                 flags=re.DOTALL,
             )
@@ -29,7 +29,6 @@ class TestCLI:
         output_path = (data_dir / "neuromorpho_config_download.json").resolve()
         cli.main(
             arguments=[
-                "--local-scheduler",
                 "--create-dependency-graph",
                 str(tmpdir / "dependency_graph.png"),
                 "Fetch",
